@@ -2,6 +2,8 @@ import click
 import validators
 import harp_gate_client.settings as settings
 import json
+import os
+import errno
 
 
 def validate_url(ctx, param, value):
@@ -12,12 +14,21 @@ def validate_url(ctx, param, value):
 
 
 def update_config_file(data):
+    if not os.path.exists(os.path.dirname(settings.PATH_TO_MS_CONFIG)):
+        try:
+            os.makedirs(os.path.dirname(settings.PATH_TO_MS_CONFIG))
+        except OSError as exc:  # Guard against race condition
+            if exc.errno != errno.EEXIST:
+                raise
+
     try:
-        with open(settings.PATH_TO_MS_CONFIG, 'w+') as outfile:
-            json.dump(data, outfile)
-    except FileNotFoundError:
         with open(settings.PATH_TO_MS_CONFIG, 'w') as outfile:
             print(outfile, data)
+            json.dump(data, outfile)
+    except FileNotFoundError:
+        with open(settings.PATH_TO_MS_CONFIG, 'w+') as outfile:
+            json.dump(data, outfile)
+
 
 
 @click.command()
